==> likewise-open_5.4.0.42111.orig.tar.gz: likewise-open-5.4.0.42111/netlogon/server/ipc/globals.c <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see 
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        globals.c
 *
 * Abstract:
 *
 *        Likewise Site Manager
 * 
 *        Inter-process communication (Server)
 *
 *        Global variables
 *
 * Authors: Krishna Ganugapati (krishnag@likewisesoftware.com)
 *          Sriram Nambakam (snambakam@likewisesoftware.com)
 */
#include "includes.h"

static LWMsgDispatchSpec gMessageHandlers[] =
{
    LWMSG_DISPATCH_BLOCK(LWNET_Q_SET_LOG_LEVEL, LWNetSrvIpcSetLogLevel),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_LOG_INFO, LWNetSrvIpcGetLogInfo),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DC_TIME, LWNetSrvIpcGetDCTime),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DC_NAME, LWNetSrvIpcGetDCName),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DOMAIN_CONTROLLER, LWNetSrvIpcGetDomainController),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_CURRENT_DOMAIN, &LWNetSrvIpcGetCurrentDomain),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DC_LIST, LWNetSrvIpcGetDCList),
    LWMSG_DISPATCH_END
};

LWMsgDispatchSpec*
LWNetSrvGetDispatchSpec(
    void
    )
{
    return gMessageHandlers;
}

==> likewise-open_6.1.0.406.orig.tar.gz: likewise-open-6.1.0.406/netlogon/server/ipc/globals.c <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see 
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        globals.c
 *
 * Abstract:
 *
 *        Likewise Site Manager
 * 
 *        Inter-process communication (Server)
 *
 *        Global variables
 *
 * Authors: Krishna Ganugapati (krishnag@likewisesoftware.com)
 *          Sriram Nambakam (snambakam@likewisesoftware.com)
 */
#include "includes.h"

static LWMsgDispatchSpec gMessageHandlers[] =
{
    LWMSG_DISPATCH_BLOCK(LWNET_Q_SET_LOG_LEVEL, LWNetSrvIpcSetLogLevel),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_LOG_INFO, LWNetSrvIpcGetLogInfo),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DC_TIME, LWNetSrvIpcGetDCTime),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DC_NAME, LWNetSrvIpcGetDCName),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DOMAIN_CONTROLLER, LWNetSrvIpcGetDomainController),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_GET_DC_LIST, LWNetSrvIpcGetDCList),
    LWMSG_DISPATCH_BLOCK(LWNET_Q_RESOLVE_NAME, LWNetSrvIpcResolveName),
    LWMSG_DISPATCH_END
};

LWMsgDispatchSpec*
LWNetSrvGetDispatchSpec(
    void
    )
{
    return gMessageHandlers;
}
